@@ -24,7 +24,7 @@
 //#include <gnome.h>
 #include <gtkmm/main.h>
 #include <libgnome/gnome-init.h> // For gnome_program_init().
-#include <libintl.h>
+#include <glibmm/i18n.h>
 
 
 
@@ -33,7 +33,6 @@
 #include "application.h"
 
 
-
 class ExampleOptionGroup : public Glib::OptionGroup
 { 
 public:
@@ -58,7 +57,7 @@ ExampleOptionGroup::ExampleOptionGroup()
 int 
 main(int argc, char* argv[])
 {
-  //Make this application use the current locale for gettext() translation:
+  //Make this application use the current locale for _() translation:
   bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);  //LOCALEDIR is defined in the Makefile.am
   bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
   textdomain(GETTEXT_PACKAGE);
@@ -81,7 +80,6 @@ main(int argc, char* argv[])
   }
 */
 
-
   //We use python for calculated-fields:
   Py_Initialize();
 
@@ -90,13 +88,16 @@ main(int argc, char* argv[])
     //Initialize gnome_program, so that we can use gnome_help_display().    
     gnome_program_init (PACKAGE, VERSION, LIBGNOME_MODULE, argc, argv,
                             GNOME_PROGRAM_STANDARD_PROPERTIES, 0);
-                            
+
     Gtk::Main mainInstance(argc, argv, context);
     Bakery::init();
 
     //Get command-line parameters, if any:
     Glib::ustring input_uri = group.m_arg_filename;
 
+    //debugging:
+    //input_uri = "file:///home/murrayc/cvs/gnome212/glom/examples/example_smallbusiness.glom";
+
 
     // Main app
     Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_main");
@@ -121,7 +122,7 @@ main(int argc, char* argv[])
 
   //We use python for calculated-fields:
   Py_Finalize();
-  
+
   return 0;
 }
 
